pub struct OptionGreeks {
pub instrument_id: InstrumentId,
pub convention: GreeksConvention,
pub greeks: OptionGreekValues,
pub mark_iv: Option<f64>,
pub bid_iv: Option<f64>,
pub ask_iv: Option<f64>,
pub underlying_price: Option<f64>,
pub open_interest: Option<f64>,
pub ts_event: UnixNanos,
pub ts_init: UnixNanos,
}Expand description
Exchange-provided option Greeks and implied volatility for a single instrument.
Fields
instrument_id: InstrumentIdThe instrument ID these Greeks apply to.
convention: GreeksConventionThe numeraire convention these Greeks are expressed in.
greeks: OptionGreekValuesCore Greek sensitivity values.
mark_iv: Option<f64>Mark implied volatility.
bid_iv: Option<f64>Bid implied volatility.
ask_iv: Option<f64>Ask implied volatility.
underlying_price: Option<f64>Underlying price at time of Greeks calculation.
open_interest: Option<f64>Open interest for the instrument.
ts_event: UnixNanosUNIX timestamp (nanoseconds) when the event occurred.
ts_init: UnixNanosUNIX timestamp (nanoseconds) when the instance was initialized.
Implementations
Sourceimpl OptionGreeks
impl OptionGreeks
Sourcepub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
pub fn from_pyobject(obj: &Bound<'_, PyAny>) -> PyResult<Self>
Creates an OptionGreeks from a Python object.
Errors
Returns an error if the Python object is missing required attributes.